<?php

namespace FiloBlu\OrderStatus\Observer;

use \Magento\Framework\Event\ObserverInterface;
use \Magento\Framework\Event\Observer;

/**
 * Observer on PayPal IPN notifications and set order status accordingly
 * This observer needs the core patch paypal_ipn_events.patch
 */
 
 class UpdateStatusPayPalIpn implements ObserverInterface {
    
    /**
     * @var \Psr\Log\LoggerInterface $logger
     */  
    protected $_logger;
    
    const IPN_COMPLETED_ORDER_STATUS = 'payment_confirmed';
    const IPN_AUTHORIZED_ORDER_STATUS = 'confirmed';
    const DEBUG_LOG_ACTIVE = TRUE;
	
    /**
     * @param \Psr\Log\LoggerInterface $logger
     */  
	public function __construct(
		\Psr\Log\LoggerInterface $logger
	){
		$this->_logger = $logger;
	}

    /**
     * Process order
     *
     * @param \Magento\Framework\Event\Observer $observer
     */
    public function execute(Observer $observer){
        /* @var $order \Magento\Sales\Model\Order */
        $event = $observer->getEvent()->getEvent();
        if (self::DEBUG_LOG_ACTIVE) {
            $this->_logger->addInfo("FiloBlu\UpdateStatusPayPalIpn\Observer: Processing IPN event: " . $event);
        }
        $order = $observer->getEvent()->getOrder();
        switch ($event) {
            case 'capture':
                $order->addStatusHistoryComment(
                    __('Order processed by mod2-order-status'), self::IPN_COMPLETED_ORDER_STATUS
                );
                if (self::DEBUG_LOG_ACTIVE) {
                    $this->_logger->addInfo("FiloBlu\UpdateStatusPayPalIpn\Observer: Order status has been set to " . self::IPN_COMPLETED_ORDER_STATUS);
                }
                break;
            case 'authorization':
                $order->addStatusHistoryComment(
                    __('Order processed by mod2-order-status'), self::IPN_AUTHORIZED_ORDER_STATUS
                );
                if (self::DEBUG_LOG_ACTIVE) {
                    $this->_logger->addInfo("FiloBlu\UpdateStatusPayPalIpn\Observer: Order status has been set to " . self::IPN_AUTHORIZED_ORDER_STATUS);
                }
                break;
        }
        return TRUE;
    }
}